@@ -1,5 +1,5 @@
 /*
- * $Id: eruby_lib.c,v 1.17 2001/09/03 07:52:16 shugo Exp $
+ * $Id: eruby_lib.c,v 1.19 2003/07/29 03:42:56 shugo Exp $
  * Copyright (C) 2000  ZetaBITS, Inc.
  * Copyright (C) 2000  Information-technology Promotion Agency, Japan
  * Copyright (C) 2000  Shugo Maeda <shugo@modruby.net>
@@ -34,6 +34,7 @@
 #include <signal.h>
 
 #include "ruby.h"
+#include "regex.h"
 #include "eruby.h"
 #include "config.h"
 
@@ -127,8 +128,9 @@ int eruby_parse_options(int argc, char **argv, int *optind)
 	if (*s == '-') s++;
 	switch (*s) {
 	case 'M':
-	    if (set_mode(++s) == -1)
+	    if (set_mode(++s) == -1) {
 		result = 2; break;
+	    }
 	    s++;
 	    goto again;
 	case 'K':
@@ -575,6 +577,14 @@ static VALUE eruby_compile(eruby_compiler_t *compiler)
 		if (prevc < 0) output_literal(compiler, "print \"");
 		output_char(compiler, c);
 		prevc = c;
+                if (ismbchar(c)) {
+                    int i, len = mbclen(c) - 1;
+                    
+                    for (i = 0; i < len; i++) {
+                        c = nextc(compiler);
+                        output_char(compiler, c);
+                    }
+                }
 		break;
 	    }
 	}
